Neko 1.99.7
A portable framework for high-order spectral element flow simulations
Loading...
Searching...
No Matches
dudxyz_kernel.h File Reference
#include "elem_block.h"
Include dependency graph for dudxyz_kernel.h:
This graph shows which files directly or indirectly include this file:

Go to the source code of this file.

Functions

template<typename T , const int LX, const int CHUNKS>
__global__ void dudxyz_kernel_1d (T *__restrict__ du, const T *__restrict__ u, const T *__restrict__ dr, const T *__restrict__ ds, const T *__restrict__ dt, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ jacinv)
 
template<typename T , const int LX, const int EB>
__global__ void __launch_bounds__ ((LX *LX *EB)) dudxyz_kernel_kstep(T *__restrict__ du
 
 if (eb==0)
 
 for (int k=0;k< LX;++k)
 
 __syncthreads ()
 

Variables

__global__ void const T *__restrict__ u
 
__global__ void const T *__restrict__ const T *__restrict__ dr
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ ds
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dt
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ jacinv
 
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const int nelv
 
__shared__ T shdx [LX *LX]
 
__shared__ T shdy [LX *LX]
 
__shared__ T shdz [LX *LX]
 
const int eb = (EB == 1) ? 0 : threadIdx.z
 
const int e_blk = blockIdx.x * EB + eb
 
const bool active = (EB == 1) ? true : (e_blk < nelv)
 
const int e = active ? e_blk : (nelv - 1)
 
const int sh = eb * LX * LX
 
const int j = threadIdx.y
 
const int i = threadIdx.x
 
const int ij = i + j * LX
 
const int ele = e*LX*LX*LX
 
T ru [LX]
 
T rdr [LX]
 
T rds [LX]
 
T rdt [LX]
 
T rjacinv [LX]
 

Function Documentation

◆ __launch_bounds__()

template<typename T , const int LX, const int EB>
__global__ void __launch_bounds__ ( (LX *LX *EB )

◆ __syncthreads()

__syncthreads ( )
Here is the caller graph for this function:

◆ dudxyz_kernel_1d()

template<typename T , const int LX, const int CHUNKS>
__global__ void dudxyz_kernel_1d ( T *__restrict__  du,
const T *__restrict__  u,
const T *__restrict__  dr,
const T *__restrict__  ds,
const T *__restrict__  dt,
const T *__restrict__  dx,
const T *__restrict__  dy,
const T *__restrict__  dz,
const T *__restrict__  jacinv 
)

Device kernel for derivative

Definition at line 44 of file dudxyz_kernel.h.

Here is the call graph for this function:

◆ for()

for ( )

Definition at line 163 of file dudxyz_kernel.h.

Here is the call graph for this function:

◆ if()

if ( eb  = = 0)

Definition at line 150 of file dudxyz_kernel.h.

Variable Documentation

◆ active

const bool active = (EB == 1) ? true : (e_blk < nelv)

Definition at line 142 of file dudxyz_kernel.h.

◆ dr

◆ ds

◆ dt

◆ dx

◆ dy

◆ dz

◆ e

const int e = active ? e_blk : (nelv - 1)

Definition at line 143 of file dudxyz_kernel.h.

◆ e_blk

const int e_blk = blockIdx.x * EB + eb

Definition at line 138 of file dudxyz_kernel.h.

◆ eb

const int eb = (EB == 1) ? 0 : threadIdx.z

Definition at line 137 of file dudxyz_kernel.h.

◆ ele

const int ele = e*LX*LX*LX

Definition at line 148 of file dudxyz_kernel.h.

◆ i

Definition at line 146 of file dudxyz_kernel.h.

◆ ij

const int ij = i + j * LX

Definition at line 147 of file dudxyz_kernel.h.

◆ j

const int j = threadIdx.y

Definition at line 145 of file dudxyz_kernel.h.

◆ jacinv

◆ nelv

Initial value:
{
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__shared__ T shu[LX *LX]

Definition at line 122 of file dudxyz_kernel.h.

◆ rdr

T rdr[LX]

Definition at line 157 of file dudxyz_kernel.h.

◆ rds

T rds[LX]

Definition at line 158 of file dudxyz_kernel.h.

◆ rdt

T rdt[LX]

Definition at line 159 of file dudxyz_kernel.h.

◆ rjacinv

T rjacinv[LX]

Definition at line 160 of file dudxyz_kernel.h.

◆ ru

T ru[LX]

Definition at line 156 of file dudxyz_kernel.h.

◆ sh

const int sh = eb * LX * LX

Definition at line 144 of file dudxyz_kernel.h.

◆ shdx

__shared__ T shdx[LX *LX]

Definition at line 126 of file dudxyz_kernel.h.

◆ shdy

__shared__ T shdy[LX *LX]

Definition at line 127 of file dudxyz_kernel.h.

◆ shdz

__shared__ T shdz[LX *LX]

Definition at line 128 of file dudxyz_kernel.h.

◆ u

Definition at line 114 of file dudxyz_kernel.h.